@@ -36,3 +36,5 @@ def test_tasks_with_wait():
     assert tasks.result("method_1") == "method_1_return"
     assert tasks.result("method_2") == 2
     assert tasks.result("method_3") is None
+    assert tasks.result("unknown") is None
+    assert tasks.result(None) is None
